data locations;
Length Location $10 Lat Lon $7;
input Location $10. Lat Lon;
cards;
Stockholm  59.3661 18.0162
Copenhagen 55.6795 12.5791
Oslo       59.9169 10.7233
Espoo      60.2241 24.6603
;
run;

proc delete data=AllLocations;
run;

%macro getTemp(Location,Lon,Lat);
filename outfil 'c:\temp\smhi.json';

/* Get Weaterdata for location */
proc http 
  url="https://opendata-download-metfcst.smhi.se/api/category/pmp3g/version/2/geotype/point/lon/&lon/lat/&lat/data.json"
  out=outfil;
run;

libname smhi json 'c:\temp\smhi.json' map="D:\LearningConference\Spring2019\ModifiedMap.txt" retain;

data Temp;
  set smhi.smhitable;
  where name='t';
	length Location $25;
	Location = "&Location";
	rename values1 = Temperature;
run;

proc append base=AllLocations data=Temp;
run;
%mend;

%macro does;
  %do i = 1 %to 4;
	  data _null_;
      RowNum = &i;
	    set locations point=RowNum;
		  call symputx("Location",location);
		  call symputx("Lat",Lat);
		  call symputx("Lon",Lon);
		  stop;
		run;
	 %getTemp(&location,&lon,&lat);
 %end;
%mend;
%does;

/*Get dates*/
proc sql noprint;
  select min(datepart(validTime)), max(datepart(validTime))
    into :minDag, :maxDag
  from AllLocations;
quit;

title "Estimated temperatures %sysfunc(putn(&minDag,date9.)) - %sysfunc(putn(&maxDag,date9.))";
ods graphics on / height=20cm width=30cm scale;
proc sgplot data=AllLocations;
  series x=validtime y=Temperature / smoothconnect group=Location  lineattrs=(thickness=2pt);
  format validTime datetime9.;
run;
ods graphics off;
title;
